@@ -1,5 +1,5 @@
 package Bio::Roary::AnnotateGroups;
-$Bio::Roary::AnnotateGroups::VERSION = '3.3.4';
+$Bio::Roary::AnnotateGroups::VERSION = '3.4.0';
 # ABSTRACT: Take in a group file and assosiated GFF files for the isolates and update the group name to the gene name
 
 
@@ -7,25 +7,26 @@ use Moose;
 use Bio::Roary::Exceptions;
 use Bio::Roary::GeneNamesFromGFF;
 use Array::Utils qw(array_minus);
-
+use List::Util qw(max min sum);
 use File::Grep qw(fgrep);
 
 has 'gff_files'          => ( is => 'ro', isa => 'ArrayRef', required => 1 );
 has 'output_filename'    => ( is => 'ro', isa => 'Str',      default  => 'reannotated_groups_file' );
 has 'groups_filename'    => ( is => 'ro', isa => 'Str',      required => 1 );
 has '_ids_to_gene_names' => ( is => 'ro', isa => 'HashRef',  lazy     => 1, builder => '_build__ids_to_gene_names' );
-has '_ids_to_product' => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
-has '_groups_to_id_names' => ( is => 'ro', isa => 'HashRef', lazy => 1, builder => '_builder__groups_to_id_names' );
-has '_output_fh' => ( is => 'ro', lazy => 1, builder => '_build__output_fh' );
+has '_ids_to_product'    => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
+has '_ids_to_gene_size'  => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
+has 'group_nucleotide_lengths'  => ( is => 'ro', isa => 'HashRef', lazy => 1, builder => '_build_group_nucleotide_lengths');
+
+has '_groups_to_id_names'   => ( is => 'ro', isa => 'HashRef', lazy => 1, builder => '_builder__groups_to_id_names' );
+has '_output_fh'            => ( is => 'ro', lazy => 1, builder => '_build__output_fh' );
 has '_groups_to_consensus_gene_names' =>
   ( is => 'rw', isa => 'HashRef', lazy => 1, builder => '_build__groups_to_consensus_gene_names' );
-has '_filtered_gff_files' => ( is => 'ro', isa => 'ArrayRef', lazy => 1, builder => '_build__filtered_gff_files' );
-has '_number_of_files'    => ( is => 'ro', isa => 'Int',      lazy => 1, builder => '_build__number_of_files' );
-has '_ids_to_groups'      => ( is => 'rw', isa => 'HashRef',  lazy => 1, builder => '_builder__ids_to_groups' );
-
-has '_group_counter' => ( is => 'rw', isa => 'Int', lazy => 1, builder => '_builder__group_counter' );
+has '_filtered_gff_files'   => ( is => 'ro', isa => 'ArrayRef', lazy => 1, builder => '_build__filtered_gff_files' );
+has '_number_of_files'      => ( is => 'ro', isa => 'Int',      lazy => 1, builder => '_build__number_of_files' );
+has '_ids_to_groups'        => ( is => 'rw', isa => 'HashRef',  lazy => 1, builder => '_builder__ids_to_groups' );
+has '_group_counter'        => ( is => 'rw', isa => 'Int', lazy => 1, builder => '_builder__group_counter' );
 has '_group_default_prefix' => ( is => 'rw', isa => 'Str', default => 'group_' );
-
 has '_ids_to_verbose_stats' => ( is => 'rw', isa => 'HashRef', lazy_build => 1 );
 
 sub BUILD {
@@ -83,6 +84,7 @@ sub _build__ids_to_gene_names {
     my ($self) = @_;
     my %ids_to_gene_names;
     my %ids_to_product;
+	my %ids_to_gene_size;
     for my $filename ( @{ $self->_filtered_gff_files } ) {
         my $gene_names_from_gff = Bio::Roary::GeneNamesFromGFF->new( gff_file => $filename );
         my %id_to_gene_lookup = %{ $gene_names_from_gff->ids_to_gene_name };
@@ -90,8 +92,12 @@ sub _build__ids_to_gene_names {
 
         my %id_to_product_lookup = %{ $gene_names_from_gff->ids_to_product };
         @ids_to_product{ keys %id_to_product_lookup } = values %id_to_product_lookup;
+		
+		my %ids_to_gene_size_lookup = %{ $gene_names_from_gff->ids_to_gene_size };
+        @ids_to_gene_size{ keys %ids_to_gene_size_lookup } = values %ids_to_gene_size_lookup;
     }
     $self->_ids_to_product( \%ids_to_product );
+	$self->_ids_to_gene_size( \%ids_to_gene_size );
 
     return \%ids_to_gene_names;
 }
@@ -118,12 +124,10 @@ sub _build__ids_to_verbose_stats {
 
             $inf = $1 if ( $line =~ m/inference=([^;]+);/ );
             $prod = $1 if ( $line =~ m/product=([^;]+)[;\n]/ );
-			
 
             my %info = ( 'inference' => $inf, 'product' => $prod );
             $verbose{$id} = \%info;
         }
-
         return \%verbose;
 }
 
@@ -196,6 +200,30 @@ sub _consensus_gene_name_for_group {
     }
 }
 
+sub _build_group_nucleotide_lengths
+{
+	my ($self) = @_;
+	my %group_nucleotide_lengths;
+    for my $group_name (keys %{ $self->_groups_to_id_names } )
+    {
+		my @gene_lengths;
+		for my $gene_id (@{$self->_groups_to_id_names->{$group_name}})
+		{
+			my $current_gene_size = $self->_ids_to_gene_size->{$gene_id};
+			next unless(defined($current_gene_size) );
+			next if($current_gene_size < 1);
+			push(@gene_lengths, $current_gene_size);
+		}
+		
+		next if(@gene_lengths == 0);
+		my $average_gene_size = (int((sum @gene_lengths)/@gene_lengths)) || 0;
+		my $min_gene_size = (min @gene_lengths) || 0;
+		my $max_gene_size = (max @gene_lengths) || 0;
+		$group_nucleotide_lengths{$group_name} = {'min' => $min_gene_size, 'max' =>$max_gene_size , 'average' => $average_gene_size};
+    }
+	return \%group_nucleotide_lengths;
+}
+
 sub _generate_groups_to_consensus_gene_names {
     my ($self) = @_;
     my %groups_to_gene_names;
@@ -325,7 +353,7 @@ Bio::Roary::AnnotateGroups - Take in a group file and assosiated GFF files for t
 
 =head1 VERSION
 
-version 3.3.4
+version 3.4.0
 
 =head1 SYNOPSIS
 
