@@ -1,5 +1,5 @@
 package Bio::Roary::GroupStatistics;
-$Bio::Roary::GroupStatistics::VERSION = '3.3.4';
+$Bio::Roary::GroupStatistics::VERSION = '3.4.0';
 # ABSTRACT: Add labels to the groups
 
 
@@ -14,7 +14,7 @@ use Bio::Roary::AnnotateGroups;
 
 has 'annotate_groups_obj' => ( is => 'ro', isa => 'Bio::Roary::AnnotateGroups', required => 1 );
 has 'analyse_groups_obj'  => ( is => 'ro', isa => 'Bio::Roary::AnalyseGroups',  required => 1 );
-has 'output_filename'     => ( is => 'ro', isa => 'Str',                            default  => 'group_statitics.csv' );
+has 'output_filename'     => ( is => 'ro', isa => 'Str',                            default  => 'gene_presence_absence.csv' );
 has 'groups_to_contigs'   => ( is => 'ro', isa => 'Maybe[HashRef]');
 
 has '_output_fh'         => ( is => 'ro', lazy => 1,           builder => '_build__output_fh' );
@@ -42,7 +42,7 @@ sub _build__text_csv_obj {
 sub fixed_headers {
     my ($self) = @_;
     my @header =
-      ( 'Gene', 'Non-unique Gene name', 'Annotation', 'No. isolates', 'No. sequences', 'Avg sequences per isolate', 'Genome Fragment','Order within Fragment', 'Accessory Fragment','Accessory Order with Fragment', 'QC' );
+      ( 'Gene', 'Non-unique Gene name', 'Annotation', 'No. isolates', 'No. sequences', 'Avg sequences per isolate', 'Genome Fragment','Order within Fragment', 'Accessory Fragment','Accessory Order with Fragment', 'QC','Min group size nuc', 'Max group size nuc', 'Avg group size nuc' );
     return \@header;
 }
 
@@ -141,10 +141,12 @@ sub _row {
       $accessory_genome_number = $self->groups_to_contigs->{$annotated_group_name}->{accessory_label};
       $accessory_order_within_fragement = $self->groups_to_contigs->{$annotated_group_name}->{accessory_order};
     }
+	
+	my $group_size = $self->annotate_groups_obj->group_nucleotide_lengths->{$group};
     
     my @row = (
         $annotated_group_name,  $duplicate_gene_name,    $annotation,
-        $num_isolates_in_group, $num_sequences_in_group, $avg_sequences_per_isolate,$genome_number,$order_within_fragement,$accessory_genome_number,$accessory_order_within_fragement,$qc_comment
+        $num_isolates_in_group, $num_sequences_in_group, $avg_sequences_per_isolate,$genome_number,$order_within_fragement,$accessory_genome_number,$accessory_order_within_fragement,$qc_comment,$group_size->{min}, $group_size->{max}, $group_size->{average}
     );
 	
 	for(my $i =0; $i < @row; $i++)
@@ -214,7 +216,7 @@ Bio::Roary::GroupStatistics - Add labels to the groups
 
 =head1 VERSION
 
-version 3.3.4
+version 3.4.0
 
 =head1 SYNOPSIS
 
