@@ -1,10 +1,11 @@
 package Bio::Roary::Output::EmblGroups;
-$Bio::Roary::Output::EmblGroups::VERSION = '3.3.4';
+$Bio::Roary::Output::EmblGroups::VERSION = '3.4.0';
 # ABSTRACT: Create a tab/embl file with the features for drawing pretty pictures
 
 
 use Moose;
 use POSIX;
+use File::Basename;
 use Bio::Roary::Exceptions;
 use Bio::Roary::AnalyseGroups;
 use Bio::Roary::AnnotateGroups;
@@ -87,7 +88,7 @@ sub _block {
         my $group_to_file_genes = $self->_groups_to_files->{$group}->{$filename};
 
         if ( defined($group_to_file_genes) && @{$group_to_file_genes} > 0 ) {
-            my $filename_cpy = $filename;
+            my $filename_cpy = basename($filename);
             $filename_cpy =~ s!\.gff\.proteome\.faa!!;
             push( @taxon_names_array, $filename_cpy );
             next;
@@ -268,7 +269,7 @@ Bio::Roary::Output::EmblGroups - Create a tab/embl file with the features for dr
 
 =head1 VERSION
 
-version 3.3.4
+version 3.4.0
 
 =head1 SYNOPSIS
 
